@@ -286,14 +286,6 @@ mark = function(
 #' # write HTML to an output file
 #' mark_html('_Hello_, **World**!', output = tempfile())
 mark_html = function(..., template = TRUE) {
-  # TODO: remove these special treatments to arguments
-  # https://github.com/ajrgodfrey/BrailleR/pull/89
-  args = list(...)
-  if ('stylesheet' %in% names(args) && 'BrailleR' %in% loadedNamespaces()) {
-    args$meta = list(css = args$stylesheet)
-    args$stylesheet = NULL
-    return(do.call(mark, c(args, list(format = 'html', template = template))))
-  }
   mark(..., format = 'html', template = template)
 }
 
